==> haskell-memotrie-0.6.9-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MemoTrie
version: 0.6.9
id: MemoTrie-0.6.9-JIBJysJvaRnAr8ld0Fp1vx
key: MemoTrie-0.6.9-JIBJysJvaRnAr8ld0Fp1vx
license: BSD-3-Clause
copyright: (c) 2008-2016 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/MemoTrie
synopsis: Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.
    .
    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>
    .
    &#169; 2008-2016 by Conal Elliott; BSD3 license.
category: Data
abi: 069d82eb38aa11cbb9af521b74069bc8
exposed: True
exposed-modules:
    Data.MemoTrie
import-dirs: /usr/lib/ghc-8.4.3/site-local/MemoTrie-0.6.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/MemoTrie-0.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/MemoTrie-0.6.9
hs-libraries: HSMemoTrie-0.6.9-JIBJysJvaRnAr8ld0Fp1vx
depends:
    base-4.11.1.0 newtype-generics-0.5.3-56ZX9foIYdqKVaMkb0ds0W
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             newtype-generics-0.5.3-56ZX9foIYdqKVaMkb0ds0W=593c709075d5ab48bfdefc57b13d8863
haddock-interfaces: /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html: /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memotrie-0.6.9-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MemoTrie
version: 0.6.9
id: MemoTrie-0.6.9-28oLHEdGbBQF099xJAOXJC
key: MemoTrie-0.6.9-28oLHEdGbBQF099xJAOXJC
license: BSD-3-Clause
copyright: (c) 2008-2016 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/MemoTrie
synopsis: Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.
    .
    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>
    .
    &#169; 2008-2016 by Conal Elliott; BSD3 license.
category: Data
abi: cdadf7df2d1d01229a20298cb5e3d95d
exposed: True
exposed-modules:
    Data.MemoTrie
import-dirs: /usr/lib/ghc-8.4.3/site-local/MemoTrie-0.6.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/MemoTrie-0.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/MemoTrie-0.6.9
hs-libraries: HSMemoTrie-0.6.9-28oLHEdGbBQF099xJAOXJC
depends:
    base-4.11.1.0 newtype-generics-0.5.3-64TJl4Ahlzq3cZhBufB7Lk
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             newtype-generics-0.5.3-64TJl4Ahlzq3cZhBufB7Lk=2c3cb2ee8bf91dbdc084c2886eb516d3
haddock-interfaces: /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html: /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
